@@ -20,7 +20,7 @@ REPOSITORY_PROVIDER = os.environ.get("DELOG_REPOSITORY_PROVIDER", '')
 REPOSITORY_NAME = os.environ.get("DELOG_REPOSITORY_NAME", '')
 REPOSITORY_BRANCH = os.environ.get("DELOG_REPOSITORY_BRANCH", 'master')
 REPOSITORY_COMMIT = os.environ.get("DELOG_REPOSITORY_COMMIT", 'latest')
-REPOSITORY_BASEPATH = os.environ.get("DELOG_REPOSITORY_BASEPATH", '')
+REPOSITORY_BASEPATH = os.environ.get("DELOG_REPOSITORY_BASEPATH", '__MATCH_CUT__')
 
 
 DELOG_LEVEL_FATAL = 6
